﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEngine.UI;

public class PlayerControllerScript : MonoBehaviour {

    public float thrustSpeed;
    public float rotationSpeed;

    public float CameraMinZoom;
    public float CameraMaxZoom;

    public float PlanetBonus;

    public GameObject thrustAnimation;
    public GameObject explodeAnimation;
    public AudioClip explodeSound;
    public Text debugText;

    private GameObject escapeMenu;
    private GameObject exitButton;

    private bool isDead;
    private bool isPaused;

    private float playerScore;

	// Use this for initialization
	void Start () {
        isDead = false;
        playerScore = 0;
        explodeSound.LoadAudioData();
        OnTriggerExit2D(null);
    }

    private void Awake()
    {
        escapeMenu = GameObject.Find("EscapeMenuCanvas");
        exitButton = GameObject.Find("ExitButton");
        exitButton.GetComponent<Button>().onClick.AddListener(GlobalScript.ExitGame);
        escapeMenu.SetActive(false);
    }

    void OnTriggerStay2D(Collider2D collider)
    {
        debugText.text = "In planet's gravity!";
    }

    void OnTriggerExit2D(Collider2D collider)
    {
        debugText.text = "";
    }

    // Update is called once per frame
    void Update () {

        if (!isDead)
        {
            Rigidbody2D shipBody = GetComponent<Rigidbody2D>();

            if (Input.GetKeyDown(KeyCode.Escape))
            {
                TogglePause();
            }

            if (!isPaused)
            {

                if (Input.GetKey(KeyCode.W) || Input.GetKey(KeyCode.UpArrow))
                {
                    thrustAnimation.SetActive(true);
                    shipBody.AddForce(transform.up * thrustSpeed * Time.deltaTime);
                }
                else
                {
                    thrustAnimation.SetActive(false);
                }
                if (Input.GetKey(KeyCode.S) || Input.GetKey(KeyCode.DownArrow))
                {
                    shipBody.AddForce(transform.up * -thrustSpeed * Time.deltaTime);
                }

                if (Input.GetKey(KeyCode.A) || Input.GetKey(KeyCode.LeftArrow))
                {
                    transform.Rotate(transform.forward * rotationSpeed * Time.deltaTime);
                }
                else if (Input.GetKey(KeyCode.D) || Input.GetKey(KeyCode.RightArrow))
                {
                    transform.Rotate(transform.forward * -rotationSpeed * Time.deltaTime);
                }

                float cameraZoom = GetComponent<Rigidbody2D>().velocity.magnitude;

                if (cameraZoom < CameraMinZoom)
                {
                    cameraZoom = CameraMinZoom;
                }
                else if (cameraZoom > CameraMaxZoom)
                {
                    cameraZoom = CameraMaxZoom;
                }

                TallyScore();

                Camera.main.orthographicSize = cameraZoom;
            }
        }

        if (isDead)
        {
            Camera.main.orthographicSize = CameraMinZoom;
            UnityEngine.SceneManagement.SceneManager.LoadScene("Game");
        }
    }

    public void DeadlyExplosion()
    {
        StartCoroutine(OnPlayerDeath());
    }

    private void TallyScore()
    {
        if (PlanetBonus < 1)
        {
            PlanetBonus = 1;
        }
        playerScore = playerScore + ((Mathf.Abs(GetComponent<Rigidbody2D>().velocity.x) + Mathf.Abs(GetComponent<Rigidbody2D>().velocity.y) * PlanetBonus) / 10);
        playerScore = Mathf.Round(playerScore);
        if (playerScore > PlayerData.HighScore)
        {
            PlayerData.HighScore = (int)playerScore;
        }
        GameObject.Find("ScoreText").GetComponent<Text>().text = playerScore.ToString() + "\r\n" + "High: " + PlayerData.HighScore.ToString();
    }

    IEnumerator OnPlayerDeath()
    {
        GameObject.Find("ShipSprite").SetActive(false);
        explodeAnimation.SetActive(true);
        GetComponent<AudioSource>().clip = explodeSound;
        GetComponent<AudioSource>().Play();
        yield return new WaitForSeconds(0.3f);
        explodeAnimation.SetActive(false);
        yield return new WaitForSeconds(0.5f);
        isDead = true;
    }

    public void TogglePause()
    {
        if (Time.timeScale == 1)
        {
            Time.timeScale = 0;
            escapeMenu.SetActive(true);
            isPaused = true;
        }
        else
        {
            Time.timeScale = 1;
            escapeMenu.SetActive(false);
            isPaused = false;
        }
    }
}
